import React from 'react';
import Paper from 'material-ui/Paper';
import _ from 'lodash';
import List, { ListItem, ListItemText, ListItemSecondaryAction } from 'material-ui/List';
import IconButton from 'material-ui/IconButton';
import Button from 'material-ui/Button';
import DeleteIcon from 'material-ui-icons/Delete';

class ValuesFilter extends React.Component {

  constructor(props) {

    super(props);

    this.selectedValues = new Set();

    this.state = {
      maxItems: this.props.maxItems || 10,
      oldMaxItems: -1
    };
  }

  addValue(val) {
    this.selectedValues.add(val);
    this.props.onChange(Array.from(this.selectedValues));
  }

  removeValue(val) {
    this.selectedValues.delete(val);
    this.props.onChange(Array.from(this.selectedValues));
  }

  toggleList() {
    this.setState({
      oldMaxItems: this.state.maxItems,
      maxItems: this.state.oldMaxItems
    })
  }


  render() {

    let availableValues = this.props.values.filter((v) => !this.selectedValues.has(v.title));

    let listSelected = Array.from(this.selectedValues);

    let shownValues = availableValues;
    let toggleButton = '';
    if (this.state.maxItems > 0 && availableValues.length > this.state.maxItems) {
      shownValues = [];
      for (var i = 0; i < this.state.maxItems; i ++) {
        shownValues.push(availableValues[i]);
      }
      toggleButton = <Button fullWidth color="primary"  onClick={this.toggleList.bind(this)}>More</Button>;
    } else {
      toggleButton = <Button fullWidth onClick={this.toggleList.bind(this)}>Less</Button>;
    }

    if (availableValues.length < this.state.maxItems || availableValues.length < this.state.oldMaxItems) {
      toggleButton = '';
    }

    return (<Paper elevation={1}>
      <div className="filter">
        <div className="filter-head">{this.props.title}</div>
        <div id="language" className="filter-content">
        {listSelected.length > 0 && <List>
          {listSelected.map((val, idx) =>
            <ListItem key={idx} className="filter-selected-value">
              <ListItemText primary={`${_.upperFirst(val)}`} />
              <ListItemSecondaryAction>
                <IconButton aria-label="Delete" onClick={() => this.removeValue(val)}>
                  <DeleteIcon />
                </IconButton>
              </ListItemSecondaryAction>
          </ListItem>)}
        </List>}

        <List>
          {shownValues.map((val, idx) =>
            <ListItem key={idx} button>
              <ListItemText
                primary={`${_.upperFirst(val.title)} (${val.count})`}
                onClick={() => this.addValue(val.title)}
              />
          </ListItem>)}
        </List>
        {toggleButton}
        </div>
      </div>
    </Paper>);

  }
}

export default ValuesFilter;

// vi: ft=javascript.jsx
